// Copyright The prometheus-operator Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by client-gen. DO NOT EDIT.

package fake

import (
	"context"
	json "encoding/json"
	"fmt"

	v1 "github.com/prometheus-operator/prometheus-operator/pkg/apis/monitoring/v1"
	monitoringv1 "github.com/prometheus-operator/prometheus-operator/pkg/client/applyconfiguration/monitoring/v1"
	autoscalingv1 "k8s.io/api/autoscaling/v1"
	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	labels "k8s.io/apimachinery/pkg/labels"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	testing "k8s.io/client-go/testing"
)

// FakePrometheuses implements PrometheusInterface
type FakePrometheuses struct {
	Fake *FakeMonitoringV1
	ns   string
}

var prometheusesResource = v1.SchemeGroupVersion.WithResource("prometheuses")

var prometheusesKind = v1.SchemeGroupVersion.WithKind("Prometheus")

// Get takes name of the prometheus, and returns the corresponding prometheus object, and an error if there is any.
func (c *FakePrometheuses) Get(ctx context.Context, name string, options metav1.GetOptions) (result *v1.Prometheus, err error) {
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewGetActionWithOptions(prometheusesResource, c.ns, name, options), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// List takes label and field selectors, and returns the list of Prometheuses that match those selectors.
func (c *FakePrometheuses) List(ctx context.Context, opts metav1.ListOptions) (result *v1.PrometheusList, err error) {
	emptyResult := &v1.PrometheusList{}
	obj, err := c.Fake.
		Invokes(testing.NewListActionWithOptions(prometheusesResource, prometheusesKind, c.ns, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}

	label, _, _ := testing.ExtractFromListOptions(opts)
	if label == nil {
		label = labels.Everything()
	}
	list := &v1.PrometheusList{ListMeta: obj.(*v1.PrometheusList).ListMeta}
	for _, item := range obj.(*v1.PrometheusList).Items {
		if label.Matches(labels.Set(item.Labels)) {
			list.Items = append(list.Items, item)
		}
	}
	return list, err
}

// Watch returns a watch.Interface that watches the requested prometheuses.
func (c *FakePrometheuses) Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error) {
	return c.Fake.
		InvokesWatch(testing.NewWatchActionWithOptions(prometheusesResource, c.ns, opts))

}

// Create takes the representation of a prometheus and creates it.  Returns the server's representation of the prometheus, and an error, if there is any.
func (c *FakePrometheuses) Create(ctx context.Context, prometheus *v1.Prometheus, opts metav1.CreateOptions) (result *v1.Prometheus, err error) {
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewCreateActionWithOptions(prometheusesResource, c.ns, prometheus, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// Update takes the representation of a prometheus and updates it. Returns the server's representation of the prometheus, and an error, if there is any.
func (c *FakePrometheuses) Update(ctx context.Context, prometheus *v1.Prometheus, opts metav1.UpdateOptions) (result *v1.Prometheus, err error) {
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewUpdateActionWithOptions(prometheusesResource, c.ns, prometheus, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *FakePrometheuses) UpdateStatus(ctx context.Context, prometheus *v1.Prometheus, opts metav1.UpdateOptions) (result *v1.Prometheus, err error) {
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceActionWithOptions(prometheusesResource, "status", c.ns, prometheus, opts), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// Delete takes name of the prometheus and deletes it. Returns an error if one occurs.
func (c *FakePrometheuses) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
	_, err := c.Fake.
		Invokes(testing.NewDeleteActionWithOptions(prometheusesResource, c.ns, name, opts), &v1.Prometheus{})

	return err
}

// DeleteCollection deletes a collection of objects.
func (c *FakePrometheuses) DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error {
	action := testing.NewDeleteCollectionActionWithOptions(prometheusesResource, c.ns, opts, listOpts)

	_, err := c.Fake.Invokes(action, &v1.PrometheusList{})
	return err
}

// Patch applies the patch and returns the patched prometheus.
func (c *FakePrometheuses) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Prometheus, err error) {
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceActionWithOptions(prometheusesResource, c.ns, name, pt, data, opts, subresources...), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// Apply takes the given apply declarative configuration, applies it and returns the applied prometheus.
func (c *FakePrometheuses) Apply(ctx context.Context, prometheus *monitoringv1.PrometheusApplyConfiguration, opts metav1.ApplyOptions) (result *v1.Prometheus, err error) {
	if prometheus == nil {
		return nil, fmt.Errorf("prometheus provided to Apply must not be nil")
	}
	data, err := json.Marshal(prometheus)
	if err != nil {
		return nil, err
	}
	name := prometheus.Name
	if name == nil {
		return nil, fmt.Errorf("prometheus.Name must be provided to Apply")
	}
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceActionWithOptions(prometheusesResource, c.ns, *name, types.ApplyPatchType, data, opts.ToPatchOptions()), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// ApplyStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
func (c *FakePrometheuses) ApplyStatus(ctx context.Context, prometheus *monitoringv1.PrometheusApplyConfiguration, opts metav1.ApplyOptions) (result *v1.Prometheus, err error) {
	if prometheus == nil {
		return nil, fmt.Errorf("prometheus provided to Apply must not be nil")
	}
	data, err := json.Marshal(prometheus)
	if err != nil {
		return nil, err
	}
	name := prometheus.Name
	if name == nil {
		return nil, fmt.Errorf("prometheus.Name must be provided to Apply")
	}
	emptyResult := &v1.Prometheus{}
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceActionWithOptions(prometheusesResource, c.ns, *name, types.ApplyPatchType, data, opts.ToPatchOptions(), "status"), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*v1.Prometheus), err
}

// GetScale takes name of the prometheus, and returns the corresponding scale object, and an error if there is any.
func (c *FakePrometheuses) GetScale(ctx context.Context, prometheusName string, options metav1.GetOptions) (result *autoscalingv1.Scale, err error) {
	emptyResult := &autoscalingv1.Scale{}
	obj, err := c.Fake.
		Invokes(testing.NewGetSubresourceActionWithOptions(prometheusesResource, c.ns, "scale", prometheusName, options), emptyResult)

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*autoscalingv1.Scale), err
}

// UpdateScale takes the representation of a scale and updates it. Returns the server's representation of the scale, and an error, if there is any.
func (c *FakePrometheuses) UpdateScale(ctx context.Context, prometheusName string, scale *autoscalingv1.Scale, opts metav1.UpdateOptions) (result *autoscalingv1.Scale, err error) {
	emptyResult := &autoscalingv1.Scale{}
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceActionWithOptions(prometheusesResource, "scale", c.ns, scale, opts), &autoscalingv1.Scale{})

	if obj == nil {
		return emptyResult, err
	}
	return obj.(*autoscalingv1.Scale), err
}
